@@ -12,10 +12,12 @@ use vrp_core::models::{Problem, Solution};
 use vrp_core::solver::{Builder, Metrics, Telemetry, TelemetryMode};
 use vrp_pragmatic::format::problem::{deserialize_problem, PragmaticProblem};
 use vrp_pragmatic::format::solution::PragmaticSolution;
-use vrp_scientific::common::read_init_solution;
 use vrp_scientific::lilim::{LilimProblem, LilimSolution};
 use vrp_scientific::solomon::{SolomonProblem, SolomonSolution};
 
+use vrp_pragmatic::format::solution::read_init_solution as read_init_pragmatic;
+use vrp_scientific::solomon::read_init_solution as read_init_solomon;
+
 const FORMAT_ARG_NAME: &str = "FORMAT";
 const PROBLEM_ARG_NAME: &str = "PROBLEM";
 const MATRIX_ARG_NAME: &str = "matrix";
@@ -62,7 +64,7 @@ fn get_formats<'a>() -> HashMap<&'a str, (ProblemReader, InitSolutionReader, Sol
                     assert!(matrices.is_none());
                     BufReader::new(problem).read_solomon()
                 })),
-                InitSolutionReader(Box::new(|file, problem| read_init_solution(BufReader::new(file), problem).ok())),
+                InitSolutionReader(Box::new(|file, problem| read_init_solomon(BufReader::new(file), problem).ok())),
                 SolutionWriter(Box::new(|_, solution, _, writer, _| solution.write_solomon(writer))),
                 LocationWriter(Box::new(|_, _| unimplemented!())),
             ),
@@ -74,7 +76,7 @@ fn get_formats<'a>() -> HashMap<&'a str, (ProblemReader, InitSolutionReader, Sol
                     assert!(matrices.is_none());
                     BufReader::new(problem).read_lilim()
                 })),
-                InitSolutionReader(Box::new(|_file, _problem| None)),
+                InitSolutionReader(Box::new(|_file, _problem| unimplemented!())),
                 SolutionWriter(Box::new(|_, solution, _, writer, _| solution.write_lilim(writer))),
                 LocationWriter(Box::new(|_, _| unimplemented!())),
             ),
@@ -92,7 +94,7 @@ fn get_formats<'a>() -> HashMap<&'a str, (ProblemReader, InitSolutionReader, Sol
                     }
                     .map_err(|errors| errors.iter().map(|err| err.to_string()).collect::<Vec<_>>().join("\t\n"))
                 })),
-                InitSolutionReader(Box::new(|_file, _problem| None)),
+                InitSolutionReader(Box::new(|file, problem| read_init_pragmatic(BufReader::new(file), problem).ok())),
                 SolutionWriter(Box::new(|problem, solution, metrics, default_writer, geojson_writer| {
                     geojson_writer
                         .map_or(Ok(()), |geojson_writer| solution.write_geo_json(problem, geojson_writer))
@@ -294,7 +296,7 @@ pub fn run_solve(matches: &ArgMatches) {
                         };
 
                         let (solution, _, metrics) = builder
-                            .with_solutions(solution.map_or_else(Vec::new, |s| vec![Arc::new(s)]))
+                            .with_solutions(solution.map_or_else(Vec::new, |s| vec![s]))
                             .build()
                             .and_then(|solver| solver.solve())
                             .unwrap_or_else(|err| {
